@@ -367,8 +367,9 @@ void FileOpsContextManagerItem::populateOpenMenu()
 
     updateServiceList();
 
-    int idx = 0;
+    int idx = -1;
     for (const KService::Ptr &service : qAsConst(mServiceList)) {
+        ++idx;
         if (service->name() == QLatin1String("Gwenview")) {
             continue;
         }
@@ -376,7 +377,6 @@ void FileOpsContextManagerItem::populateOpenMenu()
         QAction *action = openMenu->addAction(text);
         action->setIcon(QIcon::fromTheme(service->icon()));
         action->setData(idx);
-        ++idx;
     }
 
     openMenu->addSeparator();
